@@ -34,6 +34,7 @@ import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 import javax.swing.JPanel;
 import javax.swing.SwingUtilities;
+import javax.swing.UIManager;
 
 import org.gjt.sp.jedit.EditBus.EBHandler;
 import org.gjt.sp.jedit.buffer.JEditBuffer;
@@ -89,7 +90,7 @@ import org.gjt.sp.util.ThreadUtilities;
  * @see View#getEditPanes()
  *
  * @author Slava Pestov
- * @version $Id: EditPane.java 23981 2015-08-10 14:56:24Z daleanson $
+ * @version $Id: EditPane.java 24411 2016-06-19 11:02:53Z kerik-sf $
  */
 public class EditPane extends JPanel implements BufferSetListener
 {
@@ -259,7 +260,7 @@ public class EditPane extends JPanel implements BufferSetListener
 		if(recentBuffer != null)
 			setBuffer(recentBuffer);
 		else
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 	} //}}}
 
 	//{{{ focusOnTextArea() method
@@ -309,7 +310,7 @@ public class EditPane extends JPanel implements BufferSetListener
 	public void focusBufferSwitcher()
 	{
 		if(bufferSwitcher == null)
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 		else
 		{
 			SwingUtilities.invokeLater(new Runnable()
@@ -502,7 +503,7 @@ public class EditPane extends JPanel implements BufferSetListener
 		java.util.List<Marker> markers = buffer.getMarkers();
 		if(markers.isEmpty())
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -540,7 +541,7 @@ public class EditPane extends JPanel implements BufferSetListener
 		java.util.List<Marker> markers = buffer.getMarkers();
 		if(markers.isEmpty())
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -580,7 +581,7 @@ public class EditPane extends JPanel implements BufferSetListener
 		Marker marker = buffer.getMarker(shortcut);
 		if(marker == null)
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -631,7 +632,7 @@ public class EditPane extends JPanel implements BufferSetListener
 		Marker marker = buffer.getMarker(shortcut);
 		if(marker == null)
 		{
-			getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -907,7 +908,6 @@ public class EditPane extends JPanel implements BufferSetListener
 			jEdit.getColorProperty("view.gutter.structureHighlightColor"));
 		Color backgroundColor = jEdit.getColorProperty("view.gutter.bgColor");
 		gutter.setBackground(backgroundColor);
-		textArea.setBackground(backgroundColor);
 		gutter.setForeground(
 			jEdit.getColorProperty("view.gutter.fgColor"));
 		gutter.setHighlightedForeground(
@@ -975,6 +975,9 @@ public class EditPane extends JPanel implements BufferSetListener
 
 		textArea.setCtrlForRectangularSelection(jEdit.getBooleanProperty(
 			"view.ctrlForRectangularSelection"));
+		
+		textArea.setBackground(UIManager.getDefaults().getColor(
+			"ScrollBar.background"));
 
 		textArea.propertiesChanged();
 
@@ -1043,9 +1046,9 @@ public class EditPane extends JPanel implements BufferSetListener
 		SyntaxStyle[] foldLineStyle = new SyntaxStyle[4];
 		for(int i = 0; i <= 3; i++)
 		{
-			foldLineStyle[i] = GUIUtilities.parseStyle(
+			foldLineStyle[i] = SyntaxUtilities.parseStyle(
 				jEdit.getProperty("view.style.foldLine." + i),
-				defaultFont,defaultFontSize);
+				defaultFont,defaultFontSize, true);
 		}
 		painter.setFoldLineStyle(foldLineStyle);
 	} //}}}
