@@ -26,7 +26,6 @@ package org.gjt.sp.jedit;
 //{{{ Imports
 import java.awt.datatransfer.*;
 import java.awt.Toolkit;
-import java.awt.datatransfer.DataFlavor;
 import java.io.*;
 
 import org.gjt.sp.jedit.buffer.JEditBuffer;
@@ -62,7 +61,7 @@ import org.gjt.sp.util.Log;
  *
  * @author Slava Pestov
  * @author John Gellene (API documentation)
- * @version $Id: Registers.java 23224 2013-09-30 20:51:42Z shlomy $
+ * @version $Id: Registers.java 24429 2016-06-23 03:08:58Z daleanson $
  */
 public class Registers
 {
@@ -111,7 +110,7 @@ public class Registers
 			textArea.setSelectedText("");
 		}
 		else
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 	} //}}}
 
 	//{{{ append() methods
@@ -151,7 +150,7 @@ public class Registers
 	{
 		if(cut && !textArea.isEditable())
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -231,7 +230,7 @@ public class Registers
 	{
 		if(!textArea.isEditable())
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -239,7 +238,7 @@ public class Registers
 
 		if(reg == null)
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 		Transferable transferable = reg.getTransferable();
@@ -268,7 +267,7 @@ public class Registers
 		}
 		if(selection == null)
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 		JEditBuffer buffer = textArea.getBuffer();
@@ -295,7 +294,7 @@ public class Registers
 		}
 		if(!textArea.isEditable())
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 
@@ -303,7 +302,7 @@ public class Registers
 
 		if(reg == null)
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 		Transferable transferable = reg.getTransferable();
@@ -318,7 +317,7 @@ public class Registers
 		}
 		if(selection == null)
 		{
-			textArea.getToolkit().beep();
+			javax.swing.UIManager.getLookAndFeel().provideErrorFeedback(null); 
 			return;
 		}
 		JEditBuffer buffer = textArea.getBuffer();
@@ -693,7 +692,10 @@ public class Registers
 		/**
 		 * Converts to a string.
 		 */
-		@Deprecated
+		//@Deprecated
+		// undeprecating this since the two concrete classes defined in Registers
+		// use it and several other classes depend on it.
+		// TODO: finish the work to actually deprecate this.
 		String toString();
 
 		/**
@@ -731,7 +733,7 @@ public class Registers
 		public void setValue(String value)
 		{
 			Transferable selection = new StringSelection(value);
-			clipboard.setContents(selection,null);
+			clipboard.setContents(selection, null);
 		}
 
 		/**
@@ -749,7 +751,7 @@ public class Registers
 						This is to debug clipboard problems.
 
 						Apparently, jEdit is unable to copy text from clipbard into the current
-						text buffer if the clipboard was filles using the command
+						text buffer if the clipboard was filled using the command
 							echo test | xselection CLIPBOARD -
 						under Linux. However, it seems that Java does not offer any
 						data flavor for this clipboard content (under J2RE 1.5.0_06-b05)
@@ -759,9 +761,7 @@ public class Registers
 					debugListDataFlavors(clipboard.getContents(this));
 				}
 
-				String selection = (String)clipboard
-					.getContents(this).getTransferData(
-					DataFlavor.stringFlavor);
+				String selection = (String)clipboard.getContents(this).getTransferData(DataFlavor.stringFlavor);
 
 				return stripEOLChars(selection);
 			}
