@@ -29,6 +29,7 @@ import org.gjt.sp.jedit.browser.VFSBrowser;
 import org.gjt.sp.jedit.gui.RolloverButton;
 import org.gjt.sp.jedit.io.VFS;
 import org.gjt.sp.jedit.io.VFSManager;
+import org.gjt.sp.util.GenericGUIUtilities;
 import org.gjt.sp.util.Log;
 import org.gjt.sp.util.StandardUtilities;
 import org.gjt.sp.util.StringList;
@@ -62,7 +63,7 @@ import java.util.List;
 //}}}
 
 /**
- * @version $Id: InstallPanel.java 24084 2015-09-17 18:44:47Z kerik-sf $
+ * @version $Id: InstallPanel.java 24541 2016-09-14 09:58:29Z makarius $
  */
 class InstallPanel extends JPanel implements EBComponent
 {
@@ -100,7 +101,7 @@ class InstallPanel extends JPanel implements EBComponent
 		table = new JTable(pluginModel = new PluginTableModel());
 		table.setShowGrid(false);
 		table.setIntercellSpacing(new Dimension(0,0));
-		table.setRowHeight(GUIUtilities.defaultRowHeight() + 2);
+		table.setRowHeight(GenericGUIUtilities.defaultRowHeight() + 2);
 		table.setPreferredScrollableViewportSize(new Dimension(500,200));
 		table.setDefaultRenderer(Object.class, new TextRenderer(
 			(DefaultTableCellRenderer)table.getDefaultRenderer(Object.class)));
@@ -203,7 +204,7 @@ class InstallPanel extends JPanel implements EBComponent
 				int i = table.getSelectedRow(), n = table.getModel().getRowCount();
 				if (e.getKeyChar() == '/' ||
 					e.getKeyCode() == KeyEvent.VK_DOWN && i == (n - 1) ||
-					e.getKeyCode() == KeyEvent.VK_UP && i == 0) 
+					e.getKeyCode() == KeyEvent.VK_UP && i == 0)
 				{
 					searchField.requestFocus();
 					searchField.selectAll();
@@ -401,14 +402,14 @@ class InstallPanel extends JPanel implements EBComponent
 		private int sortType = EntryCompare.COLUMN_NAME;
 		private String filterString;
 		int sortDirection = 1;
-		
+
 		//{{{ setFilterString() method
 		public void setFilterString(String filterString)
 		{
 			this.filterString = filterString;
 			updateFilteredEntries();
 		} //}}}
-		
+
 		//{{{ updateFilteredEntries() method
 		void updateFilteredEntries()
 		{
@@ -445,7 +446,7 @@ class InstallPanel extends JPanel implements EBComponent
 					{
 						continue;
 					}
-					
+
 					String s = (e.name + ' ' + e.set + ' ' + e.description).toLowerCase();
 					boolean hasAll = true;
 					boolean negative = false;
@@ -458,7 +459,7 @@ class InstallPanel extends JPanel implements EBComponent
 						}
 						if (word.length() == 0)
 							continue;
-						
+
 						if (negative == s.contains(word))
 						{
 							hasAll = false;
@@ -771,7 +772,7 @@ class InstallPanel extends JPanel implements EBComponent
 			if (pluginList == null) return;
 
 			entries.clear();
-			
+
 			for(PluginList.PluginSet set : pluginList.pluginSets)
 			{
 				for(int j = 0; j < set.plugins.size(); j++)
@@ -844,7 +845,7 @@ class InstallPanel extends JPanel implements EBComponent
 				else setValueAt(savedChecked.contains(name), i, 0);
 			}
 			if (table == null) return;
-			
+
 			table.setColumnSelectionInterval(0,0);
 			if (!savedSelection.isEmpty())
 			{
@@ -973,28 +974,25 @@ class InstallPanel extends JPanel implements EBComponent
 			{
 				Entry entry = (Entry) pluginModel.filteredEntries
 					.get(table.getSelectedRow());
-				String pattern = "<b>{0}</b>: {1}<br><b>{2}</b>: {3}<br>{4}<br><br><b>{5}</b>:<br>{6}";
+				String pattern = "<b>{0}</b>: {1}<br><b>{2}</b>: {3}<br><br>{4}";
 				List<String> params = new ArrayList<String>();
 				params.add(jEdit.getProperty("install-plugins.info.author", "Author"));
 				params.add(entry.author);
 				params.add(jEdit.getProperty("install-plugins.info.released", "Released"));
 				params.add(entry.date);
 				params.add(entry.description);
-				if (entry.dependencies == null || entry.dependencies.isEmpty())
-				{
-					pattern = "<b>{0}</b>: {1}<br><b>{2}</b>: {3} {4}";
-				} 
-				else
+				if (entry.dependencies != null && !entry.dependencies.isEmpty())
 				{
+					pattern += "<br><br><b>{5}</b>:<br>{6}";
 					params.add(jEdit.getProperty("install-plugins.info.depends", "Depends on"));
 					StringList sl = StringList.split(entry.dependencies, "\n");
 					params.add(sl.join(", "));
-					// params.add(entry.dependencies.replaceAll("\n", ", "));
 				}
 				text = MessageFormat.format(pattern, params.toArray());
 			}
 			setText(text);
 			setCaretPosition(0);
+			putClientProperty(JEditorPane.HONOR_DISPLAY_PROPERTIES, true);
 		}
 	} //}}}
 
@@ -1050,7 +1048,7 @@ class InstallPanel extends JPanel implements EBComponent
 			super(jEdit.getProperty("install-plugins.select-all"));
 			addActionListener(this);
 			pluginModel.addTableModelListener(this);
-			setEnabled(false);
+			// setEnabled(false);
 		}
 
 		@Override
@@ -1127,7 +1125,7 @@ class InstallPanel extends JPanel implements EBComponent
 		@Override
 		public void actionPerformed(ActionEvent ae)
 		{
-			
+
 			path = jEdit.getProperty(PluginManager.PROPERTY_PLUGINSET,
 				jEdit.getSettingsDirectory() + File.separator);
 			String[] selectedFiles = GUIUtilities.showVFSFileDialog(InstallPanel.this.window,
